@@ -5,10 +5,10 @@ from .filterer import (
     Domain, QueryDomain, SafeEval, FunctionParser,
     ExpressionParser, QueryParser, SqlParser)
 from .repository import (
-    Repository, MemoryRepository,
+    Repository, RepositoryResolver, MemoryRepository,
     JsonRepository, SqlRepository, RestRepository)
 
 
 __author__ = 'Knowark'
 __email__ = 'info@knowark.com'
-__version__ = '0.6.3'
+__version__ = '0.6.4'
